@@ -6,8 +6,6 @@ __email__ = 'v.starostin.m@gmail.com'
 
 
 def run():
-    import os
-    import sys
     import logging
 
     from PyQt5.QtWidgets import QApplication
@@ -27,13 +25,7 @@ def run():
     except FileNotFoundError:
         pass
 
-    reboot_exit = window.EXIT_CODE_REBOOT
-    exit_code = qapp.exec_()
-
-    if exit_code == reboot_exit:
-        python = sys.executable
-        logger.info(f'Rebooting the program with {python}...')
-        os.execl(python, python, *sys.argv)
+    return qapp.exec_()
 
 
 if __name__ == '__main__':
